@@ -1,6 +1,6 @@
 from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap.net.udp_session import UdpSession
-from whatap.trace.mod.application_wsgi import trace_handler, interceptor_db_execute
+from whatap.trace.mod.application_wsgi import trace_handler, interceptor_db_execute, interceptor_step_error, sendDebugProfile
 from whatap.util.date_util import DateUtil
 from whatap.trace.trace_context_manager import TraceContextManager
 
@@ -74,20 +74,24 @@ def instrument_sqlalchemy_engine(module):
                 interceptor_step_error(e)
             finally:
                 # print('instrument_sqlalchemy_engine 6')
-                datas = [ctx.lctx.get('dbc', ''), query]
-                ctx.elapsed = DateUtil.nowSystem() - start_time
-                # print('instrument_sqlalchemy_engine 6.1', datas)
-                UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
-                                       datas)
-                # print('instrument_sqlalchemy_engine 7')
-                count = cursor.rowcount
-                # print('instrument_sqlalchemy_engine 8')
-                if count > -1:
-                    desc = '{0}: {1}'.format('Fetch count', count)
-                    datas = [' ', ' ', desc]
-                    ctx.elapsed = 0
-                    UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-                ctx.active_sqlhash = 0
+                ctx = TraceContextManager.getLocalContext()
+                if ctx:
+                    datas = [ctx.lctx.get('dbc', ''), query]
+                    ctx.elapsed = DateUtil.nowSystem() - start_time
+                    # print('instrument_sqlalchemy_engine 6.1', datas)
+                    UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
+                                           datas)
+                    # print('instrument_sqlalchemy_engine 7')
+                    if hasattr(cursor, 'rowcount'):
+                        count = cursor.rowcount
+                        # print('instrument_sqlalchemy_engine 8')
+                        if count > -1:
+                            desc = '{0}: {1}'.format('Fetch count', count)
+                            datas = [' ', ' ', desc]
+                            ctx.elapsed = 0
+                            UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+                    ctx.active_sqlhash = 0
+
                 # print('instrument_sqlalchemy_engine 9')
 
         return trace
@@ -98,4 +102,5 @@ def instrument_sqlalchemy_engine(module):
         module.DefaultDialect.do_execute = wrapper(module.DefaultDialect.do_execute)
         module.DefaultDialect.do_executemany = wrapper(module.DefaultDialect.do_executemany)
         module.DefaultDialect.do_execute_no_params = wrapper(module.DefaultDialect.do_execute_no_params)
-        # print('database_toolkit.instrument_sqlalchemy_engine step -3')
\ No newline at end of file
+        # print('database_toolkit.instrument_sqlalchemy_engine step -3')
+
