@@ -94,6 +94,8 @@ class TraceContext(object):
         self.db_opening = False
         self.socket_connecting = False
 
+        self.mcaller_url_hash= 0
+
         self.lctx = {}
 
     def getElapsedTime(self, time=None):
@@ -127,11 +129,9 @@ class TraceContext(object):
             return self.transfer_info
 
         sb = []
-        sb.append(str(conf.PCODE))
         sb.append(str(conf.mtrace_spec))
-        if conf.mtrace_send_url_length:
-            sb.append(self.service_name[:conf.mtrace_send_url_length])
-
+        sb.append(str(self.service_hash))
+        
         transfer_info = ','.join(sb)
         return transfer_info
 
@@ -152,11 +152,8 @@ class TraceContext(object):
     def setTransferInfo(self, headerString):
         x = headerString.index(',')
         s1 = headerString[0: x]
-        self.mcaller_pcode = 0 if len(s1) == 0 else s1
-
-        y = headerString.index(',', x + 1)
-        self.mcaller_spec = headerString[x + 1: y]
-        self.mcaller_url = headerString[y + 1:]
+        self.mcaller_spec = s1
+        self.mcaller_url_hash = headerString[x + 1: ]
 
     def setTxid(self, myid):
         self.id = Hexa32.toLong32(myid)
